@@ -1,7 +1,5 @@
 package Geo::DNA;
 
-our $VERSION = "0.3.3";
-
 use common::sense;
 
 use Math::Trig qw( :pi rad2deg asin deg2rad );
@@ -13,9 +11,9 @@ our @EXPORT_OK = qw(
     encode_geo_dna
     decode_geo_dna
     neighbours_geo_dna
-    bounding_box_geo_dna
 );
 
+our $VERSION = "0.1";
 
 my $RADIUS_OF_EARTH = 6378100;
 my $ALPHABET = [ "g", "a", "t", "c", ];
@@ -26,11 +24,6 @@ my $DECODE_MAP = {
     'c' => 3,
 };
 
-sub _mod {
-    my ( $x, $m ) = @_;
-    return fmod( fmod( $x, $m ) + $m, $m);
-}
-
 sub encode_geo_dna {
     my ( @args ) = @_;
     encode( @args );
@@ -96,17 +89,13 @@ sub decode {
     my ( $lati, $loni ) = bounding_box( $geodna );
 
     my $lat = ( $lati->[0] + $lati->[1] ) / 2;
-    my $lon = ( $loni->[0] + $loni->[1] ) / 2;
+    my $lon = ( $loni->[0] + $loni->[0] ) / 2;
     if ( $options->{radians} ) {
         return ( deg2rad( $lat ), deg2rad( $lon ) );
     }
     return ( $lat, $lon );
 }
 
-sub bounding_box_geo_dna {
-    return bounding_box( @_ );
-}
-
 # locates the min/max lat/lons around the geo_dna
 sub bounding_box {
     my ( $geodna ) = @_;
@@ -143,8 +132,8 @@ sub add_vector {
     my ( $lat, $lon, $dy, $dx ) = @_;
 
     return (
-        _mod( ( $lat + 90.0 + $dy ), 180.0 ) - 90.0,
-        _mod( ( $lon + 180.0 + $dx ), 360.0 )  - 180.0
+        fmod( ( $lat + 90.0 + $dy ), 180.0 ) - 90.0,
+        fmod( ( $lon + 180.0 + $dx ), 360.0 )  - 180.0
     );
 }
 
@@ -175,7 +164,6 @@ sub neighbours {
     return $neighbours;
 }
 
-
 =head1 NAME
 
 Geo::DNA - Encode latitude and longitude in a useful string format
@@ -194,7 +182,7 @@ Geo::DNA - Encode latitude and longitude in a useful string format
 
 =head1 VERSION
 
-    0.3.3
+    0.01
 
 
 =head1 FEATURES
@@ -236,15 +224,10 @@ which has the same initial 7 characters.
 
 The original implementation of this in Python was by Michel Pelletier.
 
-This uses a concept that is very similar to Gustavo Niemeyer's geohash
-system ( http://geohash.org ), but encodes the latitude and longitude in a
-way that is more conducive to stem-based searching (which is probably
-the a common use of these hashing systems).
-
 
 =head2 FUNCTIONS
 
-=head3 C<encode_geo_dna>
+=head3 encode_geo_dna
 
  my $code = encode_geo_dna( latitude, longitude, options);
 
@@ -264,7 +247,7 @@ Note that any more than 22 chars and you're kinda splitting hairs.
 
 =back
 
-=head3 C<decode_geo_dna>
+=head3 decode_geo_dna
 
  my ( $lat, $lon ) = decode_geo_dna( code, options )
 
@@ -279,7 +262,7 @@ If true, the values returned will be in radians.
 =back
 
 
-=head3 C<neighbours_geo_dna>
+=head3 neighbours_geo_dna
 
  my $neighbours = neighbours_geo_dna( $code );
 
@@ -293,9 +276,9 @@ The precision (ie. string length) of the Geo::DNA codes will be the same
 as $code.
 
 
-=head3 C<bounding_box_geo_dna>
+=head3 bounding_box
 
- my ( $lats, $lons ) = Geo::DNA::bounding_box_geo_dna( $code );
+ my ( $lats, $lons ) = Geo::DNA::bounding_box( $code );
 
 This returns an arrayref containing two arrayrefs:
 
@@ -331,7 +314,7 @@ Please report bugs relevant to C<GeoDNA> to E<lt>info[at]kyledawkins.comE<gt>.
 
 =head1 CONTRIBUTING
 
-The github repository is at git://github.com/quile/geodna-perl.git.
+The github repository is at https://quile@github.com/quile/geodna-perl.git
 
 
 =head1 SEE ALSO
@@ -352,4 +335,4 @@ it under the same terms as Perl itself.
 
 =cut
 
-1;
+1;
\ No newline at end of file
